==> webkit2gtk_2.38.2.orig.tar.xz: webkitgtk-2.38.2/Source/WebCore/html/LazyLoadFrameObserver.h <==
/*
 * Copyright (C) 2020 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "IntersectionObserver.h"

namespace WebCore {

class Document;
class Element;
class HTMLIFrameElement;

class LazyLoadFrameObserver {
    WTF_MAKE_FAST_ALLOCATED;
public:
    LazyLoadFrameObserver(HTMLIFrameElement&);

    void observe(const AtomString& frameURL, const ReferrerPolicy&);
    void unobserve();

    AtomString frameURL() const { return m_frameURL; }
    ReferrerPolicy referrerPolicy() const { return m_referrerPolicy; }

private:
    IntersectionObserver* intersectionObserver(Document&);
    bool isObserved(Element&) const;

    HTMLIFrameElement& m_element;
    AtomString m_frameURL;
    ReferrerPolicy m_referrerPolicy;
    RefPtr<IntersectionObserver> m_observer;
};

} // namespace

==> webkit2gtk_2.48.5.orig.tar.xz: webkitgtk-2.48.5/Source/WebCore/html/LazyLoadFrameObserver.h <==
/*
 * Copyright (C) 2020 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "IntersectionObserver.h"
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class Document;
class Element;
class HTMLIFrameElement;

class LazyLoadFrameObserver {
    WTF_MAKE_TZONE_ALLOCATED(LazyLoadFrameObserver);
public:
    LazyLoadFrameObserver(HTMLIFrameElement&);

    void observe(const AtomString& frameURL, const ReferrerPolicy&);
    void unobserve();

    AtomString frameURL() const { return m_frameURL; }
    ReferrerPolicy referrerPolicy() const { return m_referrerPolicy; }

private:
    IntersectionObserver* intersectionObserver(Document&);
    bool isObserved(Element&) const;

    WeakRef<HTMLIFrameElement, WeakPtrImplWithEventTargetData> m_element;
    AtomString m_frameURL;
    ReferrerPolicy m_referrerPolicy;
    RefPtr<IntersectionObserver> m_observer;
};

} // namespace
